"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StatusBarItem = void 0;
const tslib_1 = require("tslib");
const classnames_1 = tslib_1.__importDefault(require("classnames"));
const react_1 = tslib_1.__importStar(require("react"));
const ide_components_1 = require("@opensumi/ide-components");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const react_hooks_1 = require("@opensumi/ide-core-browser/lib/react-hooks");
const ide_core_common_1 = require("@opensumi/ide-core-common");
const ide_theme_1 = require("@opensumi/ide-theme");
const status_bar_module_less_1 = tslib_1.__importDefault(require("./status-bar.module.less"));
const StatusBarPopover = (0, react_1.memo)((props) => {
    const commandService = (0, react_hooks_1.useInjectable)(ide_core_common_1.CommandService);
    const iconService = (0, react_hooks_1.useInjectable)(ide_theme_1.IIconService);
    const { contents } = props;
    const onClickLink = (0, react_1.useCallback)((command) => {
        if (!command) {
            return;
        }
        commandService.executeCommand(command.id, ...(command.arguments || []));
    }, []);
    return (react_1.default.createElement("div", null, contents.map((content, index) => (react_1.default.createElement("div", { key: `${content.title}-${index}`, className: status_bar_module_less_1.default.popover_content },
        react_1.default.createElement("span", null,
            content.title && (0, ide_core_browser_1.transformLabelWithCodicon)(content.title, {}, iconService.fromString.bind(iconService)),
            content.name && ` - ${content.name}`),
        content.command && (react_1.default.createElement(ide_components_1.Button, { type: 'link', title: content.command.tooltip, onClick: () => onClickLink(content.command) }, content.command.title)))))));
});
exports.StatusBarItem = (0, react_1.memo)((props) => {
    const { entryId, text, onClick, tooltip, command, ariaLabel, iconClass, className, role = 'button', hoverContents, color: propsColor, backgroundColor: propsBackgroundColor, } = props;
    const themeService = (0, react_hooks_1.useInjectable)(ide_theme_1.IThemeService);
    const openerService = (0, react_hooks_1.useInjectable)(ide_core_browser_1.IOpenerService);
    const iconService = (0, react_hooks_1.useInjectable)(ide_theme_1.IIconService);
    const disablePopover = (0, react_1.useMemo)(() => !tooltip && !hoverContents, [tooltip, hoverContents]);
    const popoverContent = (0, react_1.useMemo)(() => {
        if (hoverContents) {
            return react_1.default.createElement(StatusBarPopover, { contents: hoverContents });
        }
        if (tooltip && tooltip.value) {
            return (0, ide_core_browser_1.toMarkdown)(tooltip.value, openerService);
        }
        return ((0, ide_core_common_1.isString)(tooltip) && (react_1.default.createElement("div", { className: status_bar_module_less_1.default.popover_tooltip }, (0, ide_core_browser_1.transformLabelWithCodicon)(tooltip, {}, iconService.fromString.bind(iconService)))));
    }, [tooltip]);
    const getColor = (color) => {
        var _a, _b;
        if (!color) {
            return '';
        }
        if ((0, ide_core_common_1.isThemeColor)(color)) {
            return (_b = (_a = themeService.getColor(color)) === null || _a === void 0 ? void 0 : _a.toString()) !== null && _b !== void 0 ? _b : '';
        }
        return color;
    };
    return (react_1.default.createElement("div", { id: entryId, className: (0, classnames_1.default)(status_bar_module_less_1.default.element, className, {
            [status_bar_module_less_1.default.hasCommand]: command || onClick,
        }), onClick: onClick, style: {
            color: getColor(propsColor),
            backgroundColor: getColor(propsBackgroundColor),
        }, "aria-label": ariaLabel },
        react_1.default.createElement(ide_components_1.Popover, { id: `${entryId}-popover`, content: popoverContent, trigger: ide_components_1.PopoverTriggerType.hover, delay: 200, position: ide_components_1.PopoverPosition.top, disable: disablePopover },
            react_1.default.createElement("div", { className: status_bar_module_less_1.default.popover_item },
                iconClass && react_1.default.createElement("span", { key: -1, className: (0, classnames_1.default)(status_bar_module_less_1.default.icon, iconClass) }),
                text &&
                    (0, ide_core_browser_1.transformLabelWithCodicon)(text, {}, iconService.fromString.bind(iconService), (text, index) => (react_1.default.createElement("span", { key: `${text}-${index}`, style: { height: '22px', lineHeight: '22px' }, "aria-label": ariaLabel, role: role }, (0, ide_core_browser_1.replaceLocalizePlaceholder)(text))))))));
});
//# sourceMappingURL=status-bar-item.view.js.map